OC.L10N.register(
    "photos",
    {
    "Public link" : "Openbare skakel",
    "Photos" : "Foto’s",
    "Videos" : "Video's ",
    "Folders" : "Vouers",
    "Favorites" : "Gunstelinge",
    "Shared with you" : "Met u gedeel",
    "Tags" : "Etikette",
    "Back" : "Terug",
    "Save" : "Bewaar",
    "Shared by" : "Gedeel deur",
    "An error occurred" : "'n Fout het voorgekom",
    "Favorite" : "Gunsteling",
    "Go back" : "Gaan terug",
    "Add folder" : "Voeg 'n gids by",
    "Home" : "Tuis",
    "View" : "Bekyk",
    "Remove from favorites" : "Verwyder uit gunstelinge",
    "Details" : "Besonderhede",
    "Add" : "Voeg by"
},
"nplurals=2; plural=(n != 1);");
